==> open-xchange-documents-ui_7.6.0.orig.tar.bz2: open-xchange-documents-ui-7.6.0/ui/apps/io.ox/office/spreadsheet/model/operations.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) Open-Xchange Inc., 2006-2012
 * Mail: info@open-xchange.com
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/spreadsheet/model/operations',
    ['io.ox/office/tk/utils',
     'io.ox/office/editframework/model/operationsgenerator'
    ], function (Utils, OperationsGenerator) {

    'use strict';

    // class SpreadsheetOperationsGenerator ===================================

    /**
     * An instance of this class contains an operations array and provides
     * methods to generate operations for various element nodes.
     *
     * @constructor
     *
     * @extends OperationsGenerator
     *
     * @param {SpreadsheetDocumentStyles} documentStyles
     *  Global collection with the style sheet containers and custom formatting
     *  containers of a spreadsheet document.
     */
    function SpreadsheetOperationsGenerator(documentStyles) {

        // base constructor ---------------------------------------------------

        OperationsGenerator.call(this, documentStyles);

        // methods ------------------------------------------------------------

        /**
         * Creates and appends a new operation with the property 'sheet' to the
         * operations array.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateSheetOperation = function (name, sheet, operationOptions) {
            operationOptions = _({ sheet: sheet }).extend(operationOptions);
            return this.generateOperation(name, operationOptions);
        };

        /**
         * Creates and appends a new operation with 'start' and (optional)
         * 'end' properties to the operations array addressing a column or row
         * interval. If first and last index of the interval are equal, the
         * 'end' property will be omitted in the operation.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Object} interval
         *  The zero-based column/row indexes of the interval, in the
         *  properties 'first' and 'last'.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateIntervalOperation = function (name, sheet, interval, operationOptions) {
            operationOptions = _({ start: interval.first }).extend(operationOptions);
            if (interval.first < interval.last) { operationOptions.end = interval.last; }
            return this.generateSheetOperation(name, sheet, operationOptions);
        };

        /**
         * Creates and appends a new operation with a 'start' property to the
         * operations array addressing a single cell.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Number[]} address
         *  The logical address of the cell targeted by the operation.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateCellOperation = function (name, sheet, address, operationOptions) {
            operationOptions = _({ start: address }).extend(operationOptions);
            return this.generateSheetOperation(name, sheet, operationOptions);
        };

        /**
         * Creates and appends a new operation with 'start' and (optional)
         * 'end' properties to the operations array addressing a cell range. If
         * the range addresses a single cell, the 'end' property will be
         * omitted in the operation.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Object} range
         *  The logical address of the cell range addressed by the operation.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateRangeOperation = function (name, sheet, range, operationOptions) {
            operationOptions = _({ start: range.start }).extend(operationOptions);
            if (!_.isEqual(range.start, range.end)) { operationOptions.end = range.end; }
            return this.generateSheetOperation(name, sheet, operationOptions);
        };

        /**
         * Creates and appends a new operation with a 'start' property to the
         * operations array addressing a drawing object.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index.
         *
         * @param {Number[]} position
         *  The logical position of the drawing object in the sheet.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateDrawingOperation = function (name, sheet, position, operationOptions) {
            operationOptions = _({ start: [sheet].concat(position) }).extend(operationOptions);
            return this.generateOperation(name, operationOptions);
        };

    } // class SpreadsheetOperationsGenerator

    // constants --------------------------------------------------------------

    _(SpreadsheetOperationsGenerator).extend({

        INSERT_SHEET: 'insertSheet',
        DELETE_SHEET: 'deleteSheet',
        MOVE_SHEET: 'moveSheet',
        COPY_SHEET: 'copySheet',

        SET_SHEET_NAME: 'setSheetName',
        SET_SHEET_ATTRIBUTES: 'setSheetAttributes',

        INSERT_NAME: 'insertName',
        DELETE_NAME: 'deleteName',

        INSERT_COLUMNS: 'insertColumns',
        DELETE_COLUMNS: 'deleteColumns',
        SET_COLUMN_ATTRIBUTES: 'setColumnAttributes',

        INSERT_ROWS: 'insertRows',
        DELETE_ROWS: 'deleteRows',
        SET_ROW_ATTRIBUTES: 'setRowAttributes',

        INSERT_CELLS: 'insertCells',
        DELETE_CELLS: 'deleteCells',
        MERGE_CELLS: 'mergeCells',

        INSERT_VALIDATION: 'insertValidation',
        CHANGE_VALIDATION: 'changeValidation',
        DELETE_VALIDATION: 'deleteValidation',

        SET_CELL_CONTENTS: 'setCellContents',
        FILL_CELL_RANGE: 'fillCellRange',
        CLEAR_CELL_RANGE: 'clearCellRange',
        AUTO_FILL: 'autoFill',

        INSERT_DRAWING: 'insertDrawing',
        DELETE_DRAWING: 'deleteDrawing',
        SET_DRAWING_ATTRIBUTES: 'setDrawingAttributes',

        SET_CHART_DATASERIES_ATTRIBUTES: 'setChartDataSeriesAttributes',
        INSERT_CHART_DATASERIES: 'insertChartDataSeries',
        DELETE_CHART_DATASERIES: 'deleteChartDataSeries',

        SET_CHART_AXIS_ATTRIBUTES: 'setChartAxisAttributes',
        SET_CHART_GRIDLINE_ATTRIBUTES: 'setChartGridlineAttributes',
        SET_CHART_TITLE_ATTRIBUTES: 'setChartTitleAttributes',
        SET_CHART_LEGEND_ATTRIBUTES: 'setChartLegendAttributes'
    });

    // exports ================================================================

    // derive this class from class OperationsGenerator
    return OperationsGenerator.extend({ constructor: SpreadsheetOperationsGenerator });

});

==> open-xchange-documents-ui_7.6.1.orig.tar.bz2: open-xchange-documents-ui-7.6.1/ui/apps/io.ox/office/spreadsheet/model/operations.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) Open-Xchange Inc., 2006-2012
 * Mail: info@open-xchange.com
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/spreadsheet/model/operations',
    ['io.ox/office/tk/utils',
     'io.ox/office/editframework/model/operationsgenerator'
    ], function (Utils, OperationsGenerator) {

    'use strict';

    // class SpreadsheetOperationsGenerator ===================================

    /**
     * An instance of this class contains an operations array and provides
     * methods to generate operations for various element nodes.
     *
     * @constructor
     *
     * @extends OperationsGenerator
     *
     * @param {SpreadsheetDocumentStyles} documentStyles
     *  Global collection with the style sheet containers and custom formatting
     *  containers of a spreadsheet document.
     */
    function SpreadsheetOperationsGenerator(documentStyles) {

        // base constructor ---------------------------------------------------

        OperationsGenerator.call(this, documentStyles);

        // methods ------------------------------------------------------------

        /**
         * Creates and appends a new operation with the property 'sheet' to the
         * operations array.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateSheetOperation = function (name, sheet, operationOptions) {
            operationOptions = _.extend({ sheet: sheet }, operationOptions);
            return this.generateOperation(name, operationOptions);
        };

        /**
         * Creates and appends a new operation with 'start' and (optional)
         * 'end' properties to the operations array addressing a column or row
         * interval. If first and last index of the interval are equal, the
         * 'end' property will be omitted in the operation.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Object} interval
         *  The zero-based column/row indexes of the interval, in the
         *  properties 'first' and 'last'.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateIntervalOperation = function (name, sheet, interval, operationOptions) {
            operationOptions = _.extend({ start: interval.first }, operationOptions);
            if (interval.first < interval.last) { operationOptions.end = interval.last; }
            return this.generateSheetOperation(name, sheet, operationOptions);
        };

        /**
         * Creates and appends a new operation with a 'start' property to the
         * operations array addressing a single cell.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Number[]} address
         *  The logical address of the cell targeted by the operation.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateCellOperation = function (name, sheet, address, operationOptions) {
            operationOptions = _.extend({ start: address }, operationOptions);
            return this.generateSheetOperation(name, sheet, operationOptions);
        };

        /**
         * Creates and appends a new operation with 'start' and (optional)
         * 'end' properties to the operations array addressing a cell range. If
         * the range addresses a single cell, the 'end' property will be
         * omitted in the operation.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index, will be inserted as 'sheet' property.
         *
         * @param {Object} range
         *  The logical address of the cell range addressed by the operation.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateRangeOperation = function (name, sheet, range, operationOptions) {
            operationOptions = _.extend({ start: range.start }, operationOptions);
            if (!_.isEqual(range.start, range.end)) { operationOptions.end = range.end; }
            return this.generateSheetOperation(name, sheet, operationOptions);
        };

        /**
         * Creates and appends a new operation with a 'start' property to the
         * operations array addressing a drawing object.
         *
         * @param {String} name
         *  The name of the operation.
         *
         * @param {Number} sheet
         *  The zero-based sheet index.
         *
         * @param {Number[]} position
         *  The logical position of the drawing object in the sheet.
         *
         * @param {Object} [operationOptions]
         *  Additional options that will be stored in the operation.
         *
         * @returns {Object}
         *  The created operation object.
         */
        this.generateDrawingOperation = function (name, sheet, position, operationOptions) {
            operationOptions = _.extend({ start: [sheet].concat(position) }, operationOptions);
            return this.generateOperation(name, operationOptions);
        };

    } // class SpreadsheetOperationsGenerator

    // constants --------------------------------------------------------------

    _.extend(SpreadsheetOperationsGenerator, {

        INSERT_SHEET: 'insertSheet',
        DELETE_SHEET: 'deleteSheet',
        MOVE_SHEET: 'moveSheet',
        COPY_SHEET: 'copySheet',

        SET_SHEET_NAME: 'setSheetName',
        SET_SHEET_ATTRIBUTES: 'setSheetAttributes',

        INSERT_NAME: 'insertName',
        CHANGE_NAME: 'changeName',
        DELETE_NAME: 'deleteName',

        INSERT_COLUMNS: 'insertColumns',
        DELETE_COLUMNS: 'deleteColumns',
        SET_COLUMN_ATTRIBUTES: 'setColumnAttributes',

        INSERT_ROWS: 'insertRows',
        DELETE_ROWS: 'deleteRows',
        SET_ROW_ATTRIBUTES: 'setRowAttributes',

        INSERT_CELLS: 'insertCells',
        DELETE_CELLS: 'deleteCells',
        MERGE_CELLS: 'mergeCells',

        INSERT_VALIDATION: 'insertValidation',
        CHANGE_VALIDATION: 'changeValidation',
        DELETE_VALIDATION: 'deleteValidation',

        SET_CELL_CONTENTS: 'setCellContents',
        FILL_CELL_RANGE: 'fillCellRange',
        CLEAR_CELL_RANGE: 'clearCellRange',
        AUTO_FILL: 'autoFill',

        INSERT_DRAWING: 'insertDrawing',
        DELETE_DRAWING: 'deleteDrawing',
        SET_DRAWING_ATTRIBUTES: 'setDrawingAttributes',

        SET_CHART_DATASERIES_ATTRIBUTES: 'setChartDataSeriesAttributes',
        INSERT_CHART_DATASERIES: 'insertChartDataSeries',
        DELETE_CHART_DATASERIES: 'deleteChartDataSeries',

        SET_CHART_AXIS_ATTRIBUTES: 'setChartAxisAttributes',
        SET_CHART_GRIDLINE_ATTRIBUTES: 'setChartGridlineAttributes',
        SET_CHART_TITLE_ATTRIBUTES: 'setChartTitleAttributes',
        SET_CHART_LEGEND_ATTRIBUTES: 'setChartLegendAttributes'
    });

    // exports ================================================================

    // derive this class from class OperationsGenerator
    return OperationsGenerator.extend({ constructor: SpreadsheetOperationsGenerator });

});
